Primary authors
===============

* `Matt Croydon <https://github.com/mcroydon/>`_

Contributors
============

* `Daniel Lindsley <https://github.com/toastdriven/>`_ for packaging/installation help and making hashmoji more Pythonic.
